==> gmic_2.4.5.orig.tar.xz: gmic-2.4.5/gmic-qt/src/FilterSelector/FiltersView/FilterTreeAbstractItem.h <==
/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file FilterTreeAbstractItem.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef _GMIC_QT_FILTERTREEABSTRACTITEM_H_
#define _GMIC_QT_FILTERTREEABSTRACTITEM_H_
#include <QStandardItem>
#include <QStringList>

class FilterTreeAbstractItem : public QStandardItem {
public:
  FilterTreeAbstractItem(QString text);
  ~FilterTreeAbstractItem();
  void setVisibilityItem(QStandardItem * item);
  const QString & plainText() const;
  bool isWarning() const;
  bool isVisible() const;
  void setVisibility(bool flag);
  QStringList path() const;
  static QString removeWarningPrefix(QString folderName);

protected:
  QStandardItem * _visibilityItem;

private:
  static const QChar WarningPrefix;
  QString _plainText;
  bool _isWarning;
};

#endif // _GMIC_QT_FILTERTREEABSTRACTITEM_H_

==> gmic_2.9.4.orig.tar.xz: gmic-2.9.4/gmic-qt/src/FilterSelector/FiltersView/FilterTreeAbstractItem.h <==
/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file FilterTreeAbstractItem.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef GMIC_QT_FILTERTREEABSTRACTITEM_H
#define GMIC_QT_FILTERTREEABSTRACTITEM_H
#include <QStandardItem>
#include <QStringList>

class FilterTreeAbstractItem : public QStandardItem {
public:
  FilterTreeAbstractItem(QString text);
  ~FilterTreeAbstractItem();
  void setVisibilityItem(QStandardItem * item);
  const QString & plainText() const;
  bool isWarning() const;
  bool isVisible() const;
  void setVisibility(bool flag);
  QStringList path() const;
  static QString removeWarningPrefix(QString folderName);

protected:
  QStandardItem * _visibilityItem;

private:
  static const QChar WarningPrefix;
  QString _plainText;
  bool _isWarning;
};

#endif // GMIC_QT_FILTERTREEABSTRACTITEM_H
